@@ -40,8 +40,8 @@
 #define  VERSION_APPLIC_CONTEXT	app_con  			/* the Application Context */
 
 char *versionIdentification[] = {
-        "gv 3.7.1",
-        "June 2010",
+        "gv 3.7.1.90",
+        "April 2011",
 	0
 };
 
